==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/networking/v1/NetworkPolicyOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.networking.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.networking.DoneableNetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.NetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.NetworkPolicyList;
import io.fabric8.kubernetes.api.model.networking.DoneableNetworkPolicy;

import java.util.Map;
import java.util.TreeMap;


public class NetworkPolicyOperationsImpl extends HasMetadataOperation<NetworkPolicy, NetworkPolicyList, DoneableNetworkPolicy, Resource<NetworkPolicy, DoneableNetworkPolicy>> {

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NetworkPolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("networking.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("networkpolicies"));
    this.type = NetworkPolicy.class;
    this.listType = NetworkPolicyList.class;
    this.doneableType = DoneableNetworkPolicy.class;
  }

  public NetworkPolicyOperationsImpl newInstance(OperationContext context) {
    return new NetworkPolicyOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-4.13.2-sources.jar: io/fabric8/kubernetes/client/dsl/internal/networking/v1/NetworkPolicyOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.networking.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.networking.v1.DoneableNetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyList;
import io.fabric8.kubernetes.api.model.networking.v1.DoneableNetworkPolicy;

import java.util.Map;
import java.util.TreeMap;


public class NetworkPolicyOperationsImpl extends HasMetadataOperation<NetworkPolicy, NetworkPolicyList, DoneableNetworkPolicy, Resource<NetworkPolicy, DoneableNetworkPolicy>> {

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NetworkPolicyOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NetworkPolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("networking.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("networkpolicies"));
    this.type = NetworkPolicy.class;
    this.listType = NetworkPolicyList.class;
    this.doneableType = DoneableNetworkPolicy.class;
  }

  public NetworkPolicyOperationsImpl newInstance(OperationContext context) {
    return new NetworkPolicyOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
